Module emulate

Module emulate 

Available on crate feature emulation only.

Modules

compress
Compression algorithms for TLS 1.3 certificate compression.
profile
Emulation for different browsers.

Structs

Emulation
Represents the configuration options for emulating a client profile and platform.

Enums

Platform
Selects which platform the client should look like.
Profile
Selects which client profile the request should look like.