pub struct ZstdCompressor;Available on crate feature
emulation only.Trait Implementations
Sourceimpl CertificateCompressor for ZstdCompressor
impl CertificateCompressor for ZstdCompressor
Sourcefn compress(&self) -> Codec
fn compress(&self) -> Codec
Returns the
Codec used to compress certificate chains for this algorithm.Sourcefn decompress(&self) -> Codec
fn decompress(&self) -> Codec
Returns the
Codec used to decompress certificate chains for this algorithm.Sourcefn algorithm(&self) -> CertificateCompressionAlgorithm
fn algorithm(&self) -> CertificateCompressionAlgorithm
Returns the IANA-assigned identifier of the compression algorithm.