pub struct JitterDelayLayer { /* private fields */ }Available on crate feature
tower-delay only.Expand description
A Tower Layer that introduces a jittered delay before each request.
The actual delay for each request will be randomly chosen within the range
[base - base*pct, base + base*pct].
Example
use std::time::Duration;
use wreq::Client;
use wreq_util::middleware::delay::JitterDelayLayer;
// Creates delays in range [0.8s, 1.2s] (1s ± 20%)
let client = Client::builder()
.layer(JitterDelayLayer::new(Duration::from_secs(1), 0.2))
.build()?;Implementations
Sourceimpl JitterDelayLayer
impl JitterDelayLayer
Sourcepub fn new(base: Duration, pct: f64) -> Self
pub fn new(base: Duration, pct: f64) -> Self
Create a new JitterDelayLayer with the given base delay and jitter percentage.
Arguments
base- The base delay durationpct- The jitter percentage (0.0 to 1.0), representing ±pct deviation
Example
use std::time::Duration;
use wreq_util::middleware::delay::JitterDelayLayer;
// Creates delays in range [800ms, 1200ms]
let layer = JitterDelayLayer::new(Duration::from_secs(1), 0.2);Sourcepub fn when<P, Req>(self, predicate: P) -> JitterDelayLayerWith<P>
pub fn when<P, Req>(self, predicate: P) -> JitterDelayLayerWith<P>
Apply jitter delay only to requests that satisfy a predicate.
Requests that don’t match the predicate will pass through without delay.
Example
ⓘ
use std::time::Duration;
use http::Request;
use wreq_util::middleware::delay::JitterDelayLayer;
// Only delay requests to paths starting with "/slow"
let layer = JitterDelayLayer::new(Duration::from_secs(1), 0.2)
.when(|req: &Request<_>| req.uri().path().starts_with("/slow"));Trait Implementations
Sourceimpl Clone for JitterDelayLayer
impl Clone for JitterDelayLayer
Sourcefn clone(&self) -> JitterDelayLayer
fn clone(&self) -> JitterDelayLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JitterDelayLayer
impl Debug for JitterDelayLayer